###
# Figure 1 - Map of Utila with study locations marked
###

rm(list=ls())


require(maps) 
require(mapdata)
library(GISTools)



# Reading in data
setwd("/Users/dandradibrown/Documents/My SugarSync/Publications/2016_Mesoamerican_invertebrates/data")



map.data <- readRDS("HND_adm2.rds")


# set up

png("Fig 1 Map.png", width = 6, height = 4.5, units = 'in', res = 300)


Layout <- matrix(c(2, 1, 1, 1), 2, 2) 
colSize <- c(1, 1) 
rowSize <- c(1, 1) 
layout(Layout, colSize, rowSize) 


# Main Utila map 
par(mar=c(4.1, 4.1, 2, 4.1)) 

plot(map.data, xlim=c(-87.02, -86.87), ylim=c(16.05, 16.15), col="grey")


# Axis
axis(1, at=seq(-88.0, -86.7, 0.05))
axis(3, at=seq(-88.0, -86.7, 0.05))

axis(2, at=seq(16.00, 16.2, 0.05))
axis(4, at=seq(16.00, 16.2, 0.05))

mtext("° Longitude (W)", side=1, line=2, cex=1.2)
mtext("° Latitude (N)", side=2, line=2, cex=1.2)

# Map Labels
text(x=-86.95, y=16.09, "Utila", cex=1.2)
maps::map.scale(x=-86.93, y=16.06, relwidth=0.16, ratio=FALSE)
north.arrow(xb=-86.875, yb=16.055, len=0.002, lab="N", col="black")


# Plotting survey sites
gps.points <- read.csv("2015_12_27_Utila_gps_points.csv")

points(gps.points$longitude, gps.points$latitude, pch=16, cex=3)
text(x=gps.points$longitude, y=gps.points$latitude,
     labels=1:nrow(gps.points), col="white", cex=1)


# Central America insert map
par(mar=c(0, 0, 1, 0)) 

map("world", xlim = c(-100, -70), ylim = c(5, 35),
    fill=TRUE, col='grey') 
points(gps.points$longitude[1], gps.points$latitude[1],
       pch=16, col='black', cex=1.2)
box() 


dev.off()

