###
# Figure 2 - Plotting richness, abundance and biomass
###


# set up
rm(list=ls())

setwd("/Users/dandradibrown/Documents/My SugarSync/Publications/2016_Mesoamerican_invertebrates/data")

# Reading in data
df1 <- read.csv("2016_10_13_Light_Traps_2015.csv", header=TRUE)

head(df1)
colnames(df1)


###
# Selecting just abundance
###
df2 <- df1[, c(1:3, 4:19)]

###
# Selecting just biomass
###
df3 <- df1[, c(1:3, 20:35)]


# Calculating species richness, abundance and biomass per drop
df2$all.richness <- rowSums((df2[, 4:19] > 0))
df2$all.abundance <- rowSums(df2[, 4:19])
df2$all.biomass <- rowSums(df3[, 4:19])

df4 <- df2[, c("Dive.site", "Depth", "all.richness", "all.abundance", "all.biomass")]

# calculating mean richness, abundance and biomass per site

df4 <- aggregate(. ~ Dive.site + Depth, data=df4, FUN=mean)

# standard error function
se <- function(x) {sd(x)/sqrt(length(x))}

df5 <- aggregate(. ~ Depth, data=df4, FUN=mean)
df6 <- aggregate(. ~ Depth, data=df4, FUN=se)


#  Error bar function for plotting
plot.error <- function(mean, SE, X){
  ymax <- mean + SE
  ymin <- mean - SE
  arrows(X, mean, X, ymax, angle=90, length=0.1, lwd=2)
  arrows(X, mean, X, ymin, angle=90, length=0.1, lwd=2)
}

###
# Plotting
###

png("Fig 2 Biodiversity metrics.png", width = 6, height = 4, units = 'in', res = 300)


par(mfrow=c(1, 3), cex=1.1)
par(oma=c(1, 0, 0, 0))
par(mar=c(3, 4, 1, 1))

# Richness
barplot(df5$all.richness, ylim=c(0, 12), ylab="Richness", xlab="",
        names.arg=c("15", "40"), las=1)

legend("topleft", legend="A", bty='n', adj=2)

plot.error(mean=df5$all.richness, SE=df6$all.richness, c(0.70, 1.9))

# Abundance
barplot(df5$all.abundance, ylim=c(0, 2500), ylab="Abundance", xlab="",
        names.arg=c("15", "40"), las=1)

legend("topleft", legend="B", bty='n', adj=2)

plot.error(mean=df5$all.abundance, SE=df6$all.abundance, c(0.70, 1.9))


# Biomass
barplot(df5$all.biomass, ylim=c(0, 5), ylab="Biomass / g", xlab="",
        names.arg=c("15", "40"), beside=TRUE, las=1)

legend("topleft", legend="C", bty='n', adj=2)

plot.error(mean=df5$all.biomass, SE=df6$all.biomass, c(0.70, 1.9))

mtext("Depth / m", side=1, outer=TRUE)

dev.off()