###
# Figure 3 - NMDS plots of (A) Abundance and (B) Biomass
###


# set up
rm(list=ls())

setwd("/Users/dandradibrown/Documents/My SugarSync/Publications/2016_Mesoamerican_invertebrates/data")

# Reading in data
df1 <- read.csv("2016_10_13_Light_Traps_2015.csv", header=TRUE)

head(df1)
colnames(df1)

# loading the vegan library
library(vegan)

###
# Selecting just abundance
###
df2 <- df1[, c(1:3, 4:19)]

# creating a matrix - note you only want data columns in the matrix, not descriptors (eg Region, Site, Depth etc), hence this is why we start at column 6
abu.matrix <- vegdist((df2[, 4:ncol(df2)])^(1/4))

# running nMDS
aNMDS <- metaMDS(abu.matrix, k=2)

# pulling out x and y values for plotting from the NnMDS
xa <- aNMDS$points[, 1]
ya <- aNMDS$points[, 2]


###
# Selecting just biomass
###
df3 <- df1[, c(1:3, 20:35)]

# removing samples that biomass was too low to record
df3 <- df3[- which(rowSums(df3[, 4:ncol(df3)])==0), ]

# creating a matrix - note you only want data columns in the matrix, not descriptors, hence this is why we start at column 4
bio.matrix <- vegdist((df3[, 4:ncol(df3)])^(1/4))

# running nMDS
bNMDS <- metaMDS(bio.matrix, k=2)

# pulling out x and y values for plotting from the NnMDS
xb <- bNMDS$points[, 1]
yb <- bNMDS$points[, 2]

# Setting shapes for plotting - we have 3 sites and 2 depths, so want 3 shapes and 2 colours
shapes <- c(16, 17, 18)
colours <- c("red", "blue")

####
# Plotting
####

png("Fig 3 NMDS.png", width = 6, height = 4, units = 'in', res = 300)

par(mfrow=c(1, 2))
par(mar=c(2, 2, 1, 1))

##
# Abundance - creating empty plot
##
plot(aNMDS, type='n', xlim=c(-0.4, 0.4), ylim=c(-0.4, 0.4))


# plotting points with different colours and shapes for depth
points(xa, ya, pch=shapes[as.numeric(df2$Dive.site)], col=colours[as.numeric(as.factor(df2$Depth))], cex=1.5)

# adding stress
legend('bottomright', paste("Stress = ", round(aNMDS$stress, 3), sep=""), cex=0.9, bty='n')

# Adding figure label
legend('topleft', legend="A", bty='n', adj=2)

##
# Biomass - creating empty plot
##
plot(bNMDS, type='n', xlim=c(-0.4, 0.4), ylim=c(-0.4, 0.4))


# plotting points with different colours and shapes for depth
points(xb, yb, pch=shapes[as.numeric(df3$Dive.site)], col=colours[as.numeric(as.factor(df3$Depth))], cex=1.5)

# adding stress
legend('bottomright', paste("Stress = ", round(bNMDS$stress, 3), sep=""), cex=0.9, bty='n')

# adding legend
legend('topright', legend=c("BCW", "LB", "CV", "Shallow", "MCE"), pch=c(16, 17, 18, 15, 15),
       col=c("black", "black", "black", "red", "blue"), cex=1, ncol=2)


# Adding figure label
legend('topleft', legend="B", bty='n', adj=2)

dev.off()