###
# Table 1 - PERMANOVA testing differences in light trap community for richness, abundance and biomass
###


# set up
rm(list=ls())

setwd("/Users/dandradibrown/Documents/My SugarSync/Publications/2016_Mesoamerican_invertebrates/data")

# Reading in data
df1 <- read.csv("2016_10_13_Light_Traps_2015.csv", header=TRUE)

head(df1)
colnames(df1)

# loading the vegan library
library(vegan)

###
# Selecting just abundance
###
df2 <- df1[, c(1:3, 4:19)]

# creating a matrix - note you only want data columns in the matrix, not descriptors (eg Region, Site, Depth etc), hence this is why we start at column 6
abu.matrix <- vegdist((df2[, 4:ncol(df2)])^(1/4))

###
# Selecting just biomass
###
df3 <- df1[, c(1:3, 20:35)]

# removing samples that biomass was too low to record
df3 <- df3[- which(rowSums(df3[, 4:ncol(df3)])==0), ]

# creating a matrix - note you only want data columns in the matrix, not descriptors, hence this is why we start at column 4
bio.matrix <- vegdist((df3[, 4:ncol(df3)])^(1/4))


###
# Running PERMANOVA
###

## abundance

mod1 <- adonis(abu.matrix ~ df2$Dive.site + df2$Depth,
               distance="bray", permutations = 99999)
mod1

write.csv(mod1[1], file="abundance.csv")


## biomass

mod2 <- adonis(bio.matrix ~ df3$Dive.site + df3$Depth,
               distance="bray", permutations = 99999)
mod2

write.csv(mod2[1], file="biomass.csv")


## richness

df4 <- df2

# calculating species richness
# turing all records into 1 or 0 to represent presence/absence of taxonmic group
for (i in 4:ncol(df4))
  {
  df4[which(df4[, i] > 0), i] <- 1
  } # closes the loop

df4$summary <- rowSums(df4[, 4:ncol(df4)])

# making the matrix
rich.matrix <- vegdist(df4$summary, method="euclidean")

mod3 <- adonis(rich.matrix ~ df4$Dive.site + df4$Depth,
               distance="euclidean", permutations = 99999)
mod3

write.csv(mod3[1], file="richness.csv")


