###
# Table 2 - Testing taxonomic groups for correlations with abundance CAP
###


# set up
rm(list=ls())

setwd("/Users/dandradibrown/Documents/My SugarSync/Publications/2016_Mesoamerican_invertebrates/data")

# Reading in data
df1 <- read.csv("2016_10_13_Light_Traps_2015.csv", header=TRUE)

head(df1)
colnames(df1)

# loading the vegan library
library(vegan)

###
# Selecting just abundance
###
df2 <- df1[, c(1:3, 4:19)]

# creating a matrix - note you only want data columns in the matrix, not descriptors (eg Region, Site, Depth etc), hence this is why we start at column 6
abu.matrix <- vegdist((df2[, 4:ncol(df2)])^(1/4))

# Running Constrained Analysis of Principal Coordinates (CAP)

CAP <- capscale(abu.matrix ~ df2$Dive.site + df2$Depth, distance='bray')


# Extracting CAP scores
x <- scores(CAP)$sites[, 1]
y <- scores(CAP)$sites[, 2]


# Blank vector to store taxonmic groups in that correlate with CAP
species <- c()

## Testing correlations with CAP axis

# First axis
for (i in 5:ncol(df2))
  {
  cor.result <- cor.test(df2[, i], x, method="pearson")
  if (abs(cor.result$estimate) > 0.5)
    {
    species <- c(species, colnames(df2)[i])
    } # closes if (cor.result$estimate > 0.3)
  
  }

x.species <- species


# Second axis
  species <- c()

for (i in 5:ncol(df2))
  {
  cor.result <- cor.test(df2[, i], y, method="pearson")
  if (abs(cor.result$estimate) > 0.5)
    {
    species <- c(species, colnames(df2)[i])
    } # closes if (cor.result$estimate > 0.3)
  } # closes the for loop

y.species <- species


##
# Recording differences in abundance between depth
##

# Averaging replicates within depth bands at each site to avoid pseudoreplication when calculating standard error
df3 <- aggregate(. ~ Dive.site + Depth, data=df2, FUN=mean)

species.list <- c(x.species, y.species)

results.x <- data.frame(group=species.list, m15=NA, se15=NA, m40=NA, se40=NA, f=NA, p=NA)

for (i in 1:length(species.list))
  {
  species <- species.list[i]
  
  results.x[i, "m15"] <- mean(df3[which(df3$Depth=="15"), species])
  results.x[i, "se15"] <- sd(df3[which(df3$Depth=="15"), species]) / sqrt(length(df3[which(df3$Depth=="15"), species]))
  
  results.x[i, "m40"] <- mean(df3[which(df3$Depth=="40"), species])
  results.x[i, "se40"] <- sd(df3[which(df3$Depth=="40"), species]) / sqrt(length(df3[which(df3$Depth=="40"), species]))
  
  
  temp <- adonis(vegdist(df2[, species], method="euclid") ~ df2$Depth,
                 method="euclid", strata=df2$Dive.site, permutations = 99999)
  
  
  results.x[i, "f"] <- temp$aov.tab[1,4]
  results.x[i, "p"] <- temp$aov.tab[1,6]
  } # closes the results for loop

# writing results
write.csv(results.x, file="taxa.correlations.csv")
